@@ -3,11 +3,11 @@ from traceback import FrameSummary
 from typing import List
 
 ELIDED_FILENAMES = [
-    'socketserver.py',
-    'threading.py',
+    "socketserver.py",
+    "threading.py",
     # Middleware-related stack frames
-    'django/utils/deprecation.py',
-    'django/core/handlers/exception.py',
+    "django/utils/deprecation.py",
+    "django/core/handlers/exception.py",
 ]
 
 
@@ -20,7 +20,7 @@ class Stack:  # Wrapped as an object for easier serialization
         for filename, lineno, fn, text in self.frames:
             if any(filename.endswith(elided_end) for elided_end in ELIDED_FILENAMES):
                 continue
-            filename = re.sub(r'^.+site-packages/', '~/', filename)
-            filename = re.sub(r'^.+lib/python\d\.\d/', '!/', filename)
-            stack_lines.append(f'{filename}:{lineno} ({fn}) {text}')
+            filename = re.sub(r"^.+site-packages/", "~/", filename)
+            filename = re.sub(r"^.+lib/python\d\.\d/", "!/", filename)
+            stack_lines.append(f"{filename}:{lineno} ({fn}) {text}")
         return stack_lines
