@@ -3,5 +3,5 @@ import time
 try:
     assert time.perf_counter()
     get_time = time.perf_counter
-except:
+except:  # noqa
     get_time = time.time
